package com.community.huiju.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.EmptyWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.community.commom.mode.ResponseBean;
import com.community.commom.utils.BeanTools;
import com.community.huiju.dao.BuildingOwnerInfoMapper;
import com.community.huiju.model.BuildingOwnerInfo;
import com.community.huiju.service.IBuildingOwnerInfoService;
import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 楼栋业主资料信息表 服务实现类
 * </p>
 *
 * @author weiximei
 * @since 2018-12-18
 */
@Service("iBuildingOwnerInfoService")
public class BuildingOwnerInfoServiceImpl extends ServiceImpl<BuildingOwnerInfoMapper, BuildingOwnerInfo> implements IBuildingOwnerInfoService {

    @Autowired
    private BuildingOwnerInfoMapper buildingOwnerInfoMapper;

    @Override
    public ResponseBean listQuery(String parameter) {

        ResponseBean responseBean = new ResponseBean();

        JSONObject jsonObject = JSONObject.parseObject(parameter);
        BuildingOwnerInfo buildingOwnerInfo = jsonObject.toJavaObject(BuildingOwnerInfo.class);

        Long pageNum = jsonObject.getLong("pageNum") == null ? 1 : jsonObject.getLong("pageNum");
        Long pageSize = jsonObject.getLong("pageSize") == null ? 10 : jsonObject.getLong("pageSize");

        Page<BuildingOwnerInfo> page = new Page(pageNum,pageSize);

        Map<String, Object> map = Maps.newHashMap();
        // 栋
        map.put("building",buildingOwnerInfo.getBuilding());
        // 单元
        map.put("unit",buildingOwnerInfo.getUnit());
        // 楼层
        map.put("level",buildingOwnerInfo.getLevel());
        // 房号
        map.put("room_no",buildingOwnerInfo.getRoomNo());

        QueryWrapper<BuildingOwnerInfo> queryWrapper = new QueryWrapper<>();
        queryWrapper.allEq(map,false);
        queryWrapper.like(buildingOwnerInfo.getOwnerName() != null,"owner_name",buildingOwnerInfo.getOwnerName());
        // 分页查询
        IPage<BuildingOwnerInfo> infoIPage = buildingOwnerInfoMapper.selectPage(page, queryWrapper);


        Map<String, Object> retMap = Maps.newHashMap();
        // 获取数据
        List<BuildingOwnerInfo> list = infoIPage.getRecords();

        retMap.put("data", list);
        retMap.put("total", infoIPage.getTotal());
        retMap.put("pageNum", infoIPage.getCurrent());
        retMap.put("pageSize", infoIPage.getSize());

        responseBean.addSuccess(list);

        return responseBean;
    }


    @Override
    @Transactional(rollbackFor = Exception.class)
    public ResponseBean update(String parameter) {
        ResponseBean responseBean = new ResponseBean();

        BuildingOwnerInfo buildingOwnerInfo = JSONObject.parseObject(parameter, BuildingOwnerInfo.class);
        BuildingOwnerInfo oldBuildingOwnerInfo = buildingOwnerInfoMapper.selectById(buildingOwnerInfo.getId());
        if (null == oldBuildingOwnerInfo) {
            responseBean.addError("数据不存在!");
            return responseBean;
        }

        BeanTools.copyProperties(buildingOwnerInfo, oldBuildingOwnerInfo);

        oldBuildingOwnerInfo.setUpdateDate(LocalDateTime.now());
        // 用户
        // oldBuildingOwnerInfo.setUpdateUser();

        int row = buildingOwnerInfoMapper.updateById(oldBuildingOwnerInfo);
        if (row <= 0) {
            responseBean.addError("操作失败!");
        } else {
            responseBean.addSuccess("操作成功!");
        }
        return responseBean;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ResponseBean add(String parameter) {
        ResponseBean responseBean = new ResponseBean();

        BuildingOwnerInfo buildingOwnerInfo = JSONObject.parseObject(parameter, BuildingOwnerInfo.class);
        buildingOwnerInfo.setId(null);

        int row = buildingOwnerInfoMapper.insert(buildingOwnerInfo);
        if (row <= 0) {
            responseBean.addError("操作失败!");
        } else {
            responseBean.addSuccess("操作成功!");
        }

        return responseBean;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ResponseBean deleteByIdDatch(List<Integer> ids) {
        
        ResponseBean responseBean = new ResponseBean();
        int row = buildingOwnerInfoMapper.deleteBatchIds(ids);
        if (row <= 0) {
            responseBean.addError("操作失败!");
        } else {
            responseBean.addSuccess("操作成功!");
        }
        return null;
    }
}
